MERM: Data set for the _Monetary Exchange Rate Model_

MERMR Documentation

Data set for the Monetary Exchange Rate Model

Description

The data set MERM consists of monthly observations for the log-ratios of prices p, money supply m, and industrial production y as well as the natural logarithm of nominal exchange rates against the dollar s. It covers the period January 1995 to December 2007 (T=156) for N=19 countries.

Usage

data("MERM")

Format

A long-format data panel of class 'data.frame', where the columns id_i and id_t indicate the country and month respectively.

The prepared data set is directly obtainable from the journal website: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecosta.2016.10.001")}. Supplementary Raw Research Data. This is open data under the CC BY 4.0 license.

References

Oersal, D. D. K., and Arsova, A. (2017): "Meta-Analytic Panel Cointegrating Rank Tests for Dependent Panels", Econometrics and Statistics, 2, pp. 61-72.

See Also

Other data sets: ERPT, EURO, EU_w, ICAP, MDEM, PCAP, PCIT


pvars documentation built on Nov. 5, 2025, 6:57 p.m.