| pid.grt | R Documentation |
Identifies a panel of SVEC models by utilizing a scoring algorithm
to impose long- and short-run restrictions.
See the details of SVEC in vars.
pid.grt(
x,
LR = NULL,
SR = NULL,
start = NULL,
max.iter = 100,
conv.crit = 1e-07,
maxls = 1
)
x |
An object of class ' |
LR |
Matrix. The restricted long-run impact matrix. |
SR |
Matrix. The restricted contemporaneous impact matrix. |
start |
Vector. The starting values for |
max.iter |
Integer. The maximum number of iterations. |
conv.crit |
Real number. Convergence value of algorithm. |
maxls |
Real number. Maximum movement of the parameters between two iterations of the scoring algorithm. |
List of class 'pid' with elements:
A |
Matrix. The lined-up coefficient matrices |
B |
Matrix. Mean group of the estimated structural impact matrices |
L.varx |
List of ' |
args_pid |
List of characters and integers indicating the identification methods and specifications that have been used. |
args_pvarx |
List of characters and integers indicating the estimator and specifications that have been used. |
Amisano, G. and Giannini, C. (1997): Topics in Structural VAR Econometrics, Springer, 2nd ed.
Breitung, J., Brueggemann R., and Luetkepohl, H. (2004): "Structural Vector Autoregressive Modeling and Impulse Responses", in Applied Time Series Econometrics, ed. by H. Luetkepohl and M. Kraetzig, Cambridge University Press, Cambridge.
Johansen, S. (1996): Likelihood-Based Inference in Cointegrated Vector Autoregressive Models, Advanced Texts in Econometrics, Oxford University Press, USA.
Luetkepohl, H. (2005): New Introduction to Multiple Time Series Analysis, Springer, 2nd ed.
Pfaff, B. (2008): "VAR, SVAR and SVEC Models: Implementation within R Package vars", Journal of Statistical Software, 27, pp. 1-32.
... the original SVEC by Pfaff (2008) in vars.
Note that pid.grt relies on this underlying procedure,
but allows for the additional model specifications in pvarx.VEC
and for the bootstrap procedures in sboot.pmb,
both provided by the pvars package.
Other panel identification functions:
pid.chol(),
pid.cvm(),
pid.dc(),
pid.iv()
data("PCAP")
names_k = c("g", "k", "l", "y") # variable names
names_i = levels(PCAP$id_i) # country names
names_s = NULL # optional shock names
L.data = sapply(names_i, FUN=function(i)
ts(PCAP[PCAP$id_i==i, names_k], start=1960, end=2019, frequency=1),
simplify=FALSE)
# colnames of the restriction matrices are passed as shock names #
SR = matrix(NA, nrow=4, ncol=4, dimnames=list(names_k, names_s))
SR[1, 2] = 0
SR[3, 4] = 0
LR = matrix(NA, nrow=4, ncol=4, dimnames=list(names_k, names_s))
LR[ , 3:4] = 0
# estimate and identify panel SVECM #
R.pvec = pvarx.VEC(L.data, lags=2, dim_r=2, type="Case4")
R.pid = pid.grt(R.pvec, LR=LR, SR=SR)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.