| pid.iv | R Documentation |
Given an estimated panel of VAR models, this function
uses proxy variables to partially identify
the structural impact matrix B_i of the corresponding SVAR model
y_{it} = c_{it} + A_{i1} y_{i,t-1} + ... + A_{i,p_i} y_{i,t-p_i} + u_{it}
= c_{it} + A_{i1} y_{i,t-1} + ... + A_{i,p_i} y_{i,t-p_i} + B_i \epsilon_{it}.
In general, identification procedures determine B_i up to column ordering, scale, and sign.
For a unique solution, pid.iv follows the literature on proxy SVAR.
The S columns in B_i = [B_{i,1} : B_{i,2}] of the identified shocks
\epsilon_{its}, s=1,\ldots,S, are ordered first, and the variance
\sigma^2_{\epsilon,is} = 1 is normalized to unity (see e.g. Lunsford
2015:6, Eq. 9). Further, the sign is fixed to a positive correlation
between proxy and shock series. A normalization of the impulsed shock
that may fix the size of the impact response in the IRF can be imposed
subsequently via 'normf' in irf.pvarx and sboot.pmb.
pid.iv(
x,
iv,
S2 = c("MR", "JL", "NQ"),
cov_u = "OMEGA",
R0 = NULL,
combine = c("pool", "indiv")
)
x |
An object of class ' |
iv |
List. A single ' |
S2 |
Character. Identification within multiple proxies |
cov_u |
Character. Selection of the estimated residual covariance matrices |
R0 |
Matrix. A |
combine |
Character. The combination of the individual reduced-form residuals
via ' |
List of class 'pid' with elements:
A |
Matrix. The lined-up coefficient matrices |
B |
Matrix. Mean group of the estimated structural impact matrices |
L.varx |
List of ' |
eps0 |
Matrix. The combined whitened residuals |
Q |
Matrix. The orthogonal matrix suggested by the pooled identification
procedure. |
args_pid |
List of characters and integers indicating the identification methods and specifications that have been used. |
args_pvarx |
List of characters and integers indicating the estimator and specifications that have been used. |
Mertens, K., and Ravn, M. O. (2013): "The Dynamic Effects of Personal and Corporate Income Tax Changes in the United States", American Economic Review, 103, pp. 1212-1247.
Jentsch, C., and Lunsford, K. G. (2019): "The Dynamic Effects of Personal and Corporate Income Tax Changes in the United States: Comment", American Economic Review, 109, pp. 2655-2678.
Jentsch, C., and Lunsford, K. G. (2021): "Asymptotically Valid Bootstrap Inference for Proxy SVARs", Journal of Business and Economic Statistics, 40, pp. 1876-1891.
Empting, L. F. T., Maxand, S., Oeztuerk, S., and Wagner, K. (2025): "Inference in Panel SVARs with Cross-Sectional Dependence of Unknown Form".
Other panel identification functions:
pid.chol(),
pid.cvm(),
pid.dc(),
pid.grt()
data("PCIT")
names_k = c("APITR", "ACITR", "PITB", "CITB", "GOV", "RGDP", "DEBT")
names_l = c("m_PI", "m_CI") # proxy names
names_s = paste0("epsilon[ ", c("PI", "CI"), " ]") # shock names
dim_p = 4 # lag-order
# estimate and identify panel SVAR #
L.vars = list(USA = vars::VAR(PCIT[ , names_k], p=dim_p, type="const"))
L.iv = list(USA = PCIT[-(1:dim_p), names_l])
R.pid = pid.iv(L.vars, iv=L.iv, S2="NQ", cov_u="SIGMA", combine="pool")
colnames(R.pid$B)[1:2] = names_s # labeling
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.