| pvarx | R Documentation |
Performs the (pooled) mean-group estimation of a panel VAR model.
First, VAR models are estimated for all N individual entities.
Then, their (pooled) mean-group estimate is calculated for each coefficient.
pvarx.VAR(
L.data,
lags,
type = c("const", "trend", "both", "none"),
t_D = NULL,
D = NULL,
n.factors = FALSE,
n.iterations = FALSE
)
pvarx.VEC(
L.data,
lags,
dim_r,
type = c("Case1", "Case2", "Case3", "Case4", "Case5"),
t_D1 = NULL,
t_D2 = NULL,
D1 = NULL,
D2 = NULL,
idx_pool = NULL,
n.factors = FALSE,
n.iterations = FALSE
)
L.data |
List of ' |
lags |
Integer or vector of integers.
Lag-order of the VAR models in levels, which is
either a common |
type |
Character. The conventional case of the deterministic term. |
t_D |
List of vectors. The activating break periods |
D |
List. A single ' |
n.factors |
Integer. Number of common factors to be used for SUR.
Deactivated if |
n.iterations |
Integer. The (maximum) number of iterations for the estimation of SUR resp. the pooled cointegrating vectors. |
dim_r |
Integer. Common cointegration-rank |
t_D1 |
List of vectors. The activating break periods |
t_D2 |
List of vectors. The activating break periods |
D1 |
List. A single ' |
D2 |
List. A single ' |
idx_pool |
Vector. Position |
A list of class 'pvarx' with the elements:
A |
Matrix. The lined-up coefficient matrices |
B |
Matrix. Placeholder for the structural impact matrix. |
beta |
Matrix. The |
L.varx |
List of ' |
L.data |
List of ' |
CSD |
List of measures for cross-sectional dependency.
|
args_pvarx |
List of characters and integers indicating the estimator and specifications that have been used. |
pvarx.VAR(): Mean Group (MG) of VAR models in levels.
pvarx.VEC(): (Pooled) Mean Group (PMG) of VECM.
Canova, F., and Ciccarelli, M. (2013): "Panel Vector Autoregressive Models: A Survey", Advances in Econometrics, 32, pp. 205-246.
Hsiao, C. (2014): Analysis of Panel Data, Econometric Society Monographs, Cambridge University Press, 3rd ed.
Luetkepohl, H. (2005): New Introduction to Multiple Time Series Analysis, Springer, 2nd ed.
Pesaran, M. H., and Smith R. J. (1995): "Estimating Long-Run Relationships from Dynamic Heterogeneous Panels", Journal of Econometrics, 68, pp. 79-113.
Rebucci, A. (2010): "Estimating VARs with Long Stationary Heterogeneous Panels: A Comparison of the Fixed Effect and the Mean Group Estimators", Economic Modelling, 27, pp. 1183-1198.
Ahn, S. K., and Reinsel (1990): "Estimation for Partially Nonstationary Multivariate Autoregressive Models", Journal of the American Statistical Association, 85, pp. 813-823.
Breitung, J. (2005): "A Parametric Approach to the Estimation of Cointegration Vectors in Panel Data", Econometric Reviews, 24, pp. 151-173.
Johansen, S. (1996): Likelihood-based Inference in Cointegrated Vector Autoregressive Models, Advanced Texts in Econometrics, Oxford University Press, USA.
Pesaran, M. H., Shin, Y, and Smith R. J. (1999): "Pooled Mean Group Estimation of Dynamic Heterogeneous Panels", Journal of the American Statistical Association, 94, pp. 621-634.
data("PCAP")
names_k = c("g", "k", "l", "y") # variable names
names_i = levels(PCAP$id_i) # country names
L.data = sapply(names_i, FUN=function(i)
ts(PCAP[PCAP$id_i==i, names_k], start=1960, end=2019, frequency=1),
simplify=FALSE)
R.lags = c(2, 4, 2, 3, 2, 4, 4, 2, 2, 3, 3, 3, 2, 4, 4, 2, 2, 2, 4, 2, 2, 2, 4)
names(R.lags) = names_i
### MG of VAR by OLS ###
R.t_D = list(t_shift=10) # common level shift for all countries
R.pvar = pvarx.VAR(L.data, lags=R.lags, type="both", t_D=R.t_D)
R.pirf = irf(R.pvar, n.ahead=50) # MG of individual forecast-error IRF
plot(R.pirf)
### Pooled MG of rank-restricted VAR ###
R.pvec = pvarx.VEC(L.data, lags=R.lags, dim_r=2, idx_pool=1:4, type="Case4")
R.pirf = irf(R.pvec, n.ahead=50) # MG of individual forecast-error IRF
plot(R.pirf)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.