| sboot.pmb | R Documentation |
Calculates confidence bands for impulse response functions via recursive-design bootstrap.
sboot.pmb(
x,
b.dim = c(1, 1),
n.ahead = 20,
n.boot = 500,
n.cores = 1,
fix_beta = TRUE,
deltas = cumprod((100:0)/100),
normf = NULL,
w = NULL,
MG_IRF = TRUE
)
x |
Panel VAR object of class ' |
b.dim |
Vector of two integers. The dimensions |
n.ahead |
Integer. Number of periods to consider after the initial impulse, i.e. the horizon of the IRF. |
n.boot |
Integer. Number of bootstrap iterations. |
n.cores |
Integer. Number of allocated processor cores. |
fix_beta |
Logical. If |
deltas |
Vector. Numeric weights |
normf |
Function. A given function that normalizes the |
w |
Numeric, logical, or character vector.
|
MG_IRF |
Logical. If |
In case of heterogeneous lag-orders p_i or sample sizes T_i,
the initial periods are fixed in accordance with the usage of presamples.
Only the (K \times T_{min} \times N) array of the T_{min} = min(T_1,\ldots,T_N)
last residuals is resampled.
A list of class 'sboot2' with elements:
true |
Mean group estimate of impulse response functions. |
bootstrap |
List of length |
A |
List for the VAR coefficients containing
the matrix of point estimates ' |
B |
List for the structural impact matrix containing
the matrix of point estimates ' |
L.PSI_bc |
List of the |
pvarx |
Input panel VAR object of class ' |
b.dim |
Dimensions of each block. |
nboot |
Number of correct bootstrap iterations. |
design |
Character indicating that the recursive design bootstrap has been performed. |
method |
Used bootstrap method. |
stars_t |
Matrix of ( |
stars_i |
Matrix of ( |
Brueggemann R., Jentsch, C., and Trenkler, C. (2016): "Inference in VARs with Conditional Heteroskedasticity of Unknown Form", Journal of Econometrics, 191, pp. 69-85.
Empting, L. F. T., Maxand, S., Oeztuerk, S., and Wagner, K. (2025): "Inference in Panel SVARs with Cross-Sectional Dependence of Unknown Form".
Kapetanios, G. (2008): "A Bootstrap Procedure for Panel Data Sets with many Cross-sectional Units", The Econometrics Journal, 11, pp.377-395.
Kilian, L. (1998): "Small-Sample Confidence Intervals for Impulse Response Functions", Review of Economics and Statistics, 80, pp. 218-230.
Gambacorta L., Hofmann B., and Peersman G. (2014): "The Effectiveness of Unconventional Monetary Policy at the Zero Lower Bound: A Cross-Country Analysis", Journal of Money, Credit and Banking, 46, pp. 615-642.
For the the individual counterpart see sboot.mb.
# select minimal or full example #
is_min = TRUE
n.boot = ifelse(is_min, 5, 500)
# prepare data panel #
data("PCAP")
names_k = c("g", "k", "l", "y") # variable names
names_i = levels(PCAP$id_i) # country names
L.data = sapply(names_i, FUN=function(i)
ts(PCAP[PCAP$id_i==i, names_k], start=1960, end=2019, frequency=1),
simplify=FALSE)
R.lags = c(2, 4, 2, 3, 2, 4, 4, 2, 2, 3, 3, 3, 2, 4, 4, 2, 2, 2, 4, 2, 2, 2, 4)
names(R.lags) = names_i
# estimate, identify, and bootstrap #
R.pvar = pvarx.VAR(L.data, lags=R.lags, type="both")
R.pid = pid.chol(R.pvar)
R.boot = sboot.pmb(R.pid, n.boot=n.boot)
summary(R.boot, idx_par="A", level=0.95) # VAR coefficients with 95%-confidence intervals
plot(R.boot, lowerq = c(0.05, 0.1, 0.16), upperq = c(0.95, 0.9, 0.84))
# second step of bootstrap-after-bootstrap #
R.bab = sboot.pmb(R.boot, n.boot=n.boot)
summary(R.bab, idx_par="A", level=0.95) # VAR coefficients with 95%-confidence intervals
plot(R.bab, lowerq = c(0.05, 0.1, 0.16), upperq = c(0.95, 0.9, 0.84))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.