| ERPT | R Documentation |
The data set ERPT consists of
monthly observations for the logarithm of import prices lm^*,
foreign prices lf^*, and the exchange rate against the US dollar llcusd.
It covers the period January 1995 to March 2005 (T=123) for N=7 countries.
The asterisk denotes the industry of the variables and can take values from 0 to 8:
0: Food and live animals chiefly for food
1: Beverages and tobacco
2: Crude materials (inedible, except fuels)
3: Mineral fuels, lubricants and related materials
4: Animal and vegetable oils, fats and waxes
5: Chemicals and related products
6: Manufactured goods classified chiefly by materials
7: Machines, transport equipment
8: Manufactured goods
data("ERPT")
A long-format data panel of class 'data.frame',
where the columns id_i and id_t
indicate the country and month respectively.
The prepared Eurostat data set is directly obtainable from the ZBW Journal Data Archive: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.15456/jae.2022321.0717881037")}. This is open data under the CC BY 4.0 license.
Banerjee, A., and Carrion-i-Silvestre, J. L. (2015): "Cointegration in Panel Data with Structural Breaks and Cross-Section Dependence", Journal of Applied Econometrics, 30 (1), pp. 1-23.
Other data sets:
EURO,
EU_w,
ICAP,
MDEM,
MERM,
PCAP,
PCIT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.