| EURO | R Documentation |
The data set EURO is a list of 15 'data.frame' objects,
each consisting of quarterly observations for
the first-difference of log real GDP
on national dl\_GDP or aggregated EA-level EA\_dl\_GDP,
the annualized inflation of the (log) GDP deflator
on national dl\_deflator or aggregated EA-level EA\_pi,
the EA-wide short-term interest rate IR,
the EA-wide option-adjusted bond spreads BBB,
the first-difference of log real GDP in the remaining countries dl\_GDP\_EA,
the weighted inflation in the remaining countries dl\_deflator\_EA,
the inflation of a world commodity price index WCP,
the US effective federal funds rate US\_FFR,
the trade volume in percentage of GDP trade, and
the government spending in percentage of GDP ge.
The data covers the period Q1 2001 to Q1 2020 (T=77) for
the aggregate of the Euro area (EA, first element in list) and
N=14 of its member countries (subsequent 14 elements in list).
data("EURO")
A list-format data panel of class 'list'
containing 15 'data.frame' objects with named time series.
The prepared Eurostat data set is directly obtainable from the ZBW Journal Data Archive: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.15456/jae.2024044.1425287131")}. This is open data under the CC BY 4.0 license in accordance with the deposit license of the ZBW Journal Data Archive.
Herwartz, H., and Wang, S. (2024): "Statistical Identification in Panel Structural Vector Autoregressive Models based on Independence Criteria", Journal of Applied Econometrics, 39 (4), pp. 620-639.
Other data sets:
ERPT,
EU_w,
ICAP,
MDEM,
MERM,
PCAP,
PCIT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.