| EU_w | R Documentation |
The data set EU_w is a vector of 14 elements.
These are weights for N=14 member countries of the Euro area,
constructed as the average share of their respective real GDP
over the sample period in Herwartz, Wang (2024).
data("EU_w")
A numeric vector containing 14 named elements.
The prepared Eurostat data set is directly obtainable from the ZBW Journal Data Archive: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.15456/jae.2024044.1425287131")}. This is open data under the CC BY 4.0 license in accordance with the deposit license of the ZBW Journal Data Archive.
Herwartz, H., and Wang, S. (2024): "Statistical Identification in Panel Structural Vector Autoregressive Models based on Independence Criteria", Journal of Applied Econometrics, 39 (4), pp. 620-639.
Other data sets:
ERPT,
EURO,
ICAP,
MDEM,
MERM,
PCAP,
PCIT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.