| ICAP | R Documentation |
The data set ICAP consists of annual observations for
the real GDP Y in US dollars,
the physical capital stocks K in US dollars,
the physical capital stocks KBC30 via "backcasting" in US dollars,
the number of workers LWDI providing the total labor force, and
the average years of secondary education secondary of the population.
It further reports physical measures of infrastructure given by
the electricity generation capacity EGC in megawatts,
the number of main phone lines mlines,
the kilometers of total roads troads,
the number of cell phones lines cells,
the kilometers of paved roads proads, and
the kilometers of rails rails.
It covers the period 1960 to 2000 (T=41) for N=97 countries.
The monetary values are given in US-Dollars at 2000 prices, i.e. constant PPP.
data("ICAP")
A long-format data panel of class 'data.frame',
where the columns id_i and id_t indicate the country and year
respectively. Column COUNTRY contains the complete country names.
The prepared data set is directly obtainable from the ZBW Journal Data Archive: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.15456/jae.2022321.0717368489")}. This is open data under the CC BY 4.0 license.
Calderon, C., Moral-Benito, E., and Serven, L. (2015): "Is Infrastructure Capital Productive? A Dynamic Heterogeneous Approach", Journal of Applied Econometrics, 30 (2), pp. 177-198.
Other data sets:
ERPT,
EURO,
EU_w,
MDEM,
MERM,
PCAP,
PCIT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.