| MERM | R Documentation |
The data set MERM consists of
monthly observations for the log-ratios of
prices p, money supply m, and industrial production y
as well as the natural logarithm of nominal exchange rates against the dollar s.
It covers the period January 1995 to December 2007 (T=156) for N=19 countries.
data("MERM")
A long-format data panel of class 'data.frame',
where the columns id_i and id_t
indicate the country and month respectively.
The prepared data set is directly obtainable from the journal website: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecosta.2016.10.001")}. Supplementary Raw Research Data. This is open data under the CC BY 4.0 license.
Oersal, D. D. K., and Arsova, A. (2017): "Meta-Analytic Panel Cointegrating Rank Tests for Dependent Panels", Econometrics and Statistics, 2, pp. 61-72.
Other data sets:
ERPT,
EURO,
EU_w,
ICAP,
MDEM,
PCAP,
PCIT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.