Learn R Programming

pvars (version 1.1.1)

as.t_D: Deterministic regressors in pvars

Description

Deterministic regressors can be specified via the arguments of the conventional 'type', customized 'D', and period-specific 't_D'. While 'type' is a single character and 'D' a data matrix of dimension \((n_{\bullet} \times (p+T))\), the specifications for \(\tau\) in the list 't_D' are more complex and therefore preventively checked by as.t_D.

Usage

as.t_D(x, ...)

Value

A list of class 't_D' specifying \(\tau\). Objects of this class can exclusively contain the elements:

t_break

Vector of integers. The activating periods for trend breaks \(d = [\ldots, 0, 0, 1, 2, 3, \ldots\)].

t_shift

Vector of integers. The activating periods for shifts in the constant \(d = [\ldots, 0, 0, 1, 1, 1, \ldots\)].

t_impulse

Vector of integers. The activating periods for single impulses \(d = [\ldots, 0, 0, 1, 0, 0, \ldots\)].

t_blip

Vector of integers. The activating period for blips \(d = [\ldots, 0, 0, 1, -1, 0, \ldots\)].

n.season

Integer. The number of seasons.

Arguments

x

A list of vectors for \(\tau\) to be checked. Since 'x' is just checked, Section "Value" explains function-input and -output likewise.

...

Additional arguments to be passed to or from methods.

Reference Time Interval

The complete time series (i.e. including the presample) constitutes the reference time interval. Accordingly, 'D' contains \(p+T\) observations, and 't_D' contains the positions of activating periods \(\tau\) in \(1,\ldots,(p+T)\). In a balanced panel \(p_i+T_i = T^*\), the same date implies the same \(\tau\) in \(1,\ldots,T^*\), as shown in the example for pcoint.CAIN. However, in an unbalanced panel, the same date can imply different \(\tau\) across \(i\) in accordance with the individual time interval \(1,\ldots,(p_i+T_i)\). Note that across the time series in 'L.data', it is the last observation in each data matrix that refers to the same date.

Conventional Type

An overview is given here and a detailed explanation in the package vignette.

  • type (VAR) is specified in VAR models just as in vars' VAR, namely by a 'const', a linear 'trend', 'both', or 'none' of those.

  • type_SL is used in the 'additive' SL procedure for testing the cointegration rank only, which removes the mean ('SL_mean') or mean and linear trend ('SL_trend') by GLS-detrending.

  • type (VECM) is used in the 'innovative' Johansen procedure for testing the cointegration rank and estimating the VECM. In accordance with Juselius (2007, Ch.6.3), the available model specifications are: 'Case1' for none, 'Case2' for a constant in the cointegration relation, 'Case3' for an unrestricted constant, 'Case4' for a linear trend in the cointegration relation and an unrestricted constant, or 'Case5' for an unrestricted constant and linear trend.

References

Juselius, K. (2007): The Cointegrated VAR Model: Methodology and Applications, Advanced Texts in Econometrics, Oxford University Press, USA, 2nd ed.

Examples

Run this code
t_D = list(t_impulse=c(10, 20, 35), t_shift=10)
as.t_D(t_D)

Run the code above in your browser using DataLab