Learn R Programming

pvars (version 1.1.1)

id.grt: Identification of SVEC models by imposing long- and short-run restrictions

Description

Identifies an SVEC model by utilizing a scoring algorithm to impose long- and short-run restrictions. See the details of SVEC in vars.

Usage

id.grt(
  x,
  LR = NULL,
  SR = NULL,
  start = NULL,
  max.iter = 100,
  conv.crit = 1e-07,
  maxls = 1
)

Value

List of class 'id'.

Arguments

x

VAR object of class 'varx' estimated under rank-restriction or any other that will be coerced to 'varx'.

LR

Matrix. The restricted long-run impact matrix.

SR

Matrix. The restricted contemporaneous impact matrix.

start

Vector. The starting values for \(\gamma\), set by rnorm if NULL (the default).

max.iter

Integer. The maximum number of iterations.

conv.crit

Real number. Convergence value of algorithm.

maxls

Real number. Maximum movement of the parameters between two iterations of the scoring algorithm.

References

Amisano, G. and Giannini, C. (1997): Topics in Structural VAR Econometrics, Springer, 2nd ed.

Breitung, J., Brueggemann R., and Luetkepohl, H. (2004): "Structural Vector Autoregressive Modeling and Impulse Responses", in Applied Time Series Econometrics, ed. by H. Luetkepohl and M. Kraetzig, Cambridge University Press, Cambridge.

Johansen, S. (1996): Likelihood-Based Inference in Cointegrated Vector Autoregressive Models, Advanced Texts in Econometrics, Oxford University Press, USA.

Luetkepohl, H. (2005): New Introduction to Multiple Time Series Analysis, Springer, 2nd ed.

Pfaff, B. (2008): "VAR, SVAR and SVEC Models: Implementation within R Package vars", Journal of Statistical Software, 27, pp. 1-32.

See Also

... the original SVEC by Pfaff (2008) in vars. Note that id.grt is just a graftage, but allows for the additional model specifications in VECM and for the bootstrap procedures in sboot.mb, both provided by the pvars package.

Other identification functions: id.iv()

Examples

Run this code
### reproduce basic example in "vars" ###
library(vars)
data("Canada")
names_k = c("prod", "e", "U", "rw")  # variable names
names_s = NULL  # optional shock names

# colnames of the restriction matrices are passed as shock names #
SR = matrix(NA, nrow=4, ncol=4, dimnames=list(names_k, names_s))
SR[4, 2] = 0
LR = matrix(NA, nrow=4, ncol=4, dimnames=list(names_k, names_s))
LR[1, 2:4] = 0
LR[2:4, 4] = 0

# estimate and identify SVECM #
R.vecm = VECM(y=Canada[ , names_k], dim_p=3, dim_r=1, type="Case4")
R.grt  = id.grt(R.vecm, LR=LR, SR=SR)

Run the code above in your browser using DataLab